Crate corevm_engine

Crate corevm_engine 

CoreVM engine.

This engine is used to run CoreVM services inside JAM. It can also be used to simulate running CoreVM service on the builder’s side to predict which memory pages will be used by the service.

Structs

AccumulateEngine
An engine that drives execution of accumulate and on_transfer CoreVM service entry points.
Engine
An engine that drives execution of refine CoreVM service entry point.
InputStats
This structure records which portions of the input were read/accessed by the guest.
Lookup
An implementation of ReadBlock that uses OuterVM::read_file_block to read files blocks.
WorkPackageParams
Parameters derived from work package.

Enums

AccumulationError
Accumulation error.
FatalError
Fatal engine error after which the continuation is not possible.
InitError
Engine initialization error.
RunError
Engine runtime error.

Traits

AccumulateOps
Operations that AccumulateEngine uses during accumulation.
InnerVm
A trait that abstracts JAM calls related to an inner VM.
OuterVm
A trait that abstracts JAM host-calls available in a refine environment and related to an outer VM.