pub struct InputStats {
pub accessed_imported_pages: VecSet<PageNum>,
pub num_service_messages_read: u32,
pub num_input_chunks_read: u32,
}Expand description
This structure records which portions of the input were read/accessed by the guest.
Fields
accessed_imported_pages: VecSet<PageNum>Imported memory pages that were accessed by the guest.
num_service_messages_read: u32The number of inter-service messages read by the guest.
num_input_chunks_read: u32The number of input chunks read.